@@ -567,7 +567,7 @@ KIconConfig::KIconConfig(QWidget *parent)
 
   page = new KVBox( this );
   pageItem = new KPageWidgetItem( page, i18n("Background") );
-  pageItem->setIcon( KIcon(loadIcon("background")) );
+  pageItem->setIcon( KIcon(loadIcon("preferences-other")) );
   addPage( pageItem );
   backs = new KBackgroundConfig(page);
 
